@@ -3,12 +3,17 @@ use strict;
 use warnings;
 use POSIX ();
 use File::Temp ();
-our $VERSION = '0.901';
+our $VERSION = '0.910';
+
+use constant WIN32 => $^O eq 'MSWin32';
 
 sub new {
     my ($class, $file) = @_;
     my $fh;
-    if ($file) {
+    if (WIN32) {
+        require IO::File;
+        $file ||= File::Temp::tmpnam();
+    } elsif ($file) {
         open $fh, ">>:unix", $file or die "$file: $!";
     } else {
         ($fh, $file) = File::Temp::tempfile(UNLINK => 1);
@@ -22,10 +27,11 @@ sub new {
 }
 
 sub symlink_to {
-    return unless eval { symlink "", ""; 1 };
     my ($self, $dest) = @_;
     unlink $dest;
-    symlink $self->file, $dest;
+    if (!eval { symlink $self->file, $dest }) {
+        $self->{file} = $dest;
+    }
 }
 
 sub file {
@@ -40,8 +46,9 @@ sub prefix {
 
 sub log {
     my ($self, @line) = @_;
-    my $now = POSIX::strftime('%FT%T', localtime);
+    my $now = POSIX::strftime('%Y-%m-%dT%H:%M:%S', localtime);
     my $prefix = $self->prefix;
+    local $self->{fh} = IO::File->new($self->{file}, 'a') if WIN32;
     for my $line (@line) {
         chomp $line;
         print { $self->{fh} } "$now,$prefix| $_\n" for split /\n/, $line;
@@ -51,9 +58,10 @@ sub log {
 sub log_with_fh {
     my ($self, $fh) = @_;
     my $prefix = $self->prefix;
+    local $self->{fh} = IO::File->new($self->{file}, 'a') if WIN32;
     while (my $line = <$fh>) {
         chomp $line;
-        print { $self->{fh} } "@{[POSIX::strftime('%FT%T', localtime)]},$prefix| $line\n";
+        print { $self->{fh} } "@{[POSIX::strftime('%Y-%m-%dT%H:%M:%S', localtime)]},$prefix| $line\n";
     }
 }
 
