@@ -2,13 +2,14 @@ package App::cpm::Master;
 use strict;
 use warnings;
 use utf8;
+use App::cpm::CircularDependency;
 use App::cpm::Distribution;
 use App::cpm::Job;
 use App::cpm::Logger;
 use Module::Metadata;
 use IO::Handle;
 use version;
-our $VERSION = '0.901';
+our $VERSION = '0.910';
 
 sub new {
     my ($class, %option) = @_;
@@ -32,11 +33,36 @@ sub new {
 
 sub fail {
     my $self = shift;
+
     my @fail_resolve = sort keys %{$self->{_fail_resolve}};
     my @fail_install = sort keys %{$self->{_fail_install}};
-    return if !@fail_resolve && !@fail_install;
-    my @name = map { CPAN::DistnameInfo->new($_)->distvname || $_ } @fail_install;
-    { resolve => \@fail_resolve, install => \@name };
+    my @not_installed = grep { !$self->{_fail_install}{$_->distfile} && !$_->installed } $self->distributions;
+    return if !@fail_resolve && !@fail_install && !@not_installed;
+
+    my $detector = App::cpm::CircularDependency->new;
+    for my $dist (@not_installed) {
+        my @requirements = (
+            @{ $dist->requirements || [] },
+            @{ $dist->configure_requirements || [] },
+        );
+        $detector->add($dist->distfile, $dist->provides, \@requirements);
+    }
+
+    my @name;
+    if (my $result = $detector->detect) {
+        for my $distfile (sort keys %$result) {
+            my $distvname = $self->distribution($distfile)->distvname;
+            push @name, $distvname;
+            my @requirement = @{ $result->{$distfile} };
+            my $msg = join " -> ", map { $self->distribution($_)->distvname } @requirement, $requirement[0];
+            local $self->{logger}{context} = $distvname;
+            $self->{logger}->log("Detected circular dependencies $msg");
+            $self->{logger}->log("Failed to install distribution");
+        }
+    }
+
+    push @name, map { CPAN::DistnameInfo->new($_)->distvname || $_ } @fail_install;
+    { resolve => \@fail_resolve, install => [sort @name] };
 }
 
 sub jobs { values %{shift->{jobs}} }
@@ -334,7 +360,7 @@ sub _register_resolve_result {
         return;
     }
 
-    if ($self->is_installed($job->{package}, "== $job->{version}")) { # XXX
+    if (!$job->{reinstall} and $self->is_installed($job->{package}, "== $job->{version}")) { # XXX
         my $version = $job->{version} || 0;
         my $message = "$job->{package} is up to date. ($version)";
         $self->{logger}->log($message);
